searchData={"content_type":"text/markdown","items":[{"doc":"Top-level API for creating documents.","ref":"Mudbrick.html","title":"Mudbrick","type":"module"},{"doc":"iex> import Mudbrick.TestHelper                 # import some example fonts and images\n    ...> import Mudbrick\n    ...> alias Mudbrick.Page\n    ...> new(\n    ...>   compress: true,                          # flate compression for fonts, text etc.\n    ...>   fonts: %{bodoni: [file: bodoni()]},      # register an OTF font\n    ...>   images: %{flower: [file: flower()]}      # register a JPEG\n    ...> )\n    ...> |> page(size: Page.size(:letter))\n    ...> |> image(                                  # place preregistered JPEG\n    ...>   :flower,\n    ...>   scale: {100, 100},\n    ...>   position: {50, 600}                      # in points (1/72 inch), starts at bottom left\n    ...> )\n    ...> |> text_position(200, 700)                 # set text start position from bottom left\n    ...> |> font(:bodoni, size: 14)                 # choose preregistered font\n    ...> |> colour({1, 0, 0})                       # make text red\n    ...> |> text(\"CO₂\", align: :right)              # write text in current font, with right side\n    ...>                                            # anchored to 200 points from left of page\n    ...> |> render()                                # produces iodata, can go straight to File.write/2\n    ...> |> IO.iodata_to_binary()                   # or turned into a (non-String) binary","ref":"Mudbrick.html#module-examples","title":"Examples - Mudbrick","type":"module"},{"doc":"Set the current fill colour (currently only for text).\n\nTakes an `{r, g, b}` tuple.","ref":"Mudbrick.html#colour/2","title":"Mudbrick.colour/2","type":"function"},{"doc":"Green text:\n\n    iex> Mudbrick.new(fonts: %{my_bodoni: [file: Mudbrick.TestHelper.bodoni()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.colour({0, 1, 0})\n\nInvalid:\n\n    iex> Mudbrick.new(fonts: %{my_bodoni: [file: Mudbrick.TestHelper.bodoni()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.colour({2, 0, 0})\n    ** (Mudbrick.ContentStream.InvalidColour) tuple must be made of floats or integers between 0 and 1","ref":"Mudbrick.html#colour/2-examples","title":"Examples - Mudbrick.colour/2","type":"function"},{"doc":"Compress data with the same method that PDF generation does. Useful for testing.","ref":"Mudbrick.html#compress/1","title":"Mudbrick.compress/1","type":"function"},{"doc":"iex> Mudbrick.compress([\"hi\", \"there\", [\"you\"]])\n    [<<120, 156, 203, 200, 44, 201, 72, 45, 74, 173, 204, 47, 5, 0, 23, 45, 4, 71>>]","ref":"Mudbrick.html#compress/1-example","title":"Example - Mudbrick.compress/1","type":"function"},{"doc":"Decompress data with the same method that PDF generation does. Useful for testing.","ref":"Mudbrick.html#decompress/1","title":"Mudbrick.decompress/1","type":"function"},{"doc":"iex> Mudbrick.decompress([<<120, 156, 203, 200, 44, 201, 72, 45, 74, 173, 204, 47, 5, 0, 23, 45, 4, 71>>])\n    [\"hithereyou\"]","ref":"Mudbrick.html#decompress/1-example","title":"Example - Mudbrick.decompress/1","type":"function"},{"doc":"Set the current font using a name previously registered in `new/1`.","ref":"Mudbrick.html#font/3","title":"Mudbrick.font/3","type":"function"},{"doc":"iex> Mudbrick.new(fonts: %{my_bodoni: [file: Mudbrick.TestHelper.bodoni()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.font(:my_bodoni, size: 14)\n\nForgetting to set the font is an error:\n\n    iex> Mudbrick.new(fonts: %{my_bodoni: [file: Mudbrick.TestHelper.bodoni()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.text(\"oops!\")\n    ** (Mudbrick.Font.NotSet) No font chosen\n\nForgetting to register the font is an error:\n\n    iex> Mudbrick.new()\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.font(:helvetica, size: 21)\n    ** (Mudbrick.Font.Unregistered) Unregistered font: helvetica","ref":"Mudbrick.html#font/3-example","title":"Example - Mudbrick.font/3","type":"function"},{"doc":"Insert image previously registered in `new/1` at the given coordinates.","ref":"Mudbrick.html#image/3","title":"Mudbrick.image/3","type":"function"},{"doc":"- `:position` - `{x, y}` in points, relative to bottom-left corner.\n- `:scale` - `{w, h}` in points.\n- `:skew` - `{x, y}`, passed through to PDF `cm` operator.\n\nAll options default to `{0, 0}`.","ref":"Mudbrick.html#image/3-options","title":"Options - Mudbrick.image/3","type":"function"},{"doc":"iex> Mudbrick.new(images: %{lovely_flower: [file: Mudbrick.TestHelper.flower()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.image(:lovely_flower, position: {100, 100}, scale: {100, 100})\n\n    iex> Mudbrick.new()\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.image(:my_face, position: {100, 100}, scale: {100, 100})\n    ** (Mudbrick.Image.Unregistered) Unregistered image: my_face\n\nTip: to make the image fit the page, pass e.g. `Page.size(:a4)` as the\n`scale` and `{0, 0}` as the `position`.","ref":"Mudbrick.html#image/3-examples","title":"Examples - Mudbrick.image/3","type":"function"},{"doc":"Start a new document.","ref":"Mudbrick.html#new/1","title":"Mudbrick.new/1","type":"function"},{"doc":"- `:compress` - when set to `true`, apply deflate compression to streams (if compression saves space).\n- `:fonts` - register OTF or built-in fonts for later use.\n- `:images` - register images for later use.","ref":"Mudbrick.html#new/1-options","title":"Options - Mudbrick.new/1","type":"function"},{"doc":"Register an OTF font. Pass the file's raw data to the `:file` option.\n\n    iex> Mudbrick.new(fonts: %{bodoni: [file: Mudbrick.TestHelper.bodoni()]})\n\nOr a built-in font. Note that these don't support right-alignment or special characters.\n\n    iex> Mudbrick.new(fonts: %{helvetica: [name: :Helvetica, type: :TrueType, encoding: :PDFDocEncoding]})\n\nRegister an image.\n\n    iex> Mudbrick.new(images: %{flower: [file: Mudbrick.TestHelper.flower()]})","ref":"Mudbrick.html#new/1-examples","title":"Examples - Mudbrick.new/1","type":"function"},{"doc":"Start a new page upon which future operators should apply.","ref":"Mudbrick.html#page/2","title":"Mudbrick.page/2","type":"function"},{"doc":"- `:size` - a tuple of `{width, height}`. Some standard sizes available in `Mudbrick.Page.size/1`.","ref":"Mudbrick.html#page/2-options","title":"Options - Mudbrick.page/2","type":"function"},{"doc":"Produce `iodata` from the current document.","ref":"Mudbrick.html#render/1","title":"Mudbrick.render/1","type":"function"},{"doc":"Write text at the current position. Repeated calls to this do not produce newlines.","ref":"Mudbrick.html#text/3","title":"Mudbrick.text/3","type":"function"},{"doc":"- `:align` - either `:left` or `:right`. When `:right`, text is right-aligned\n  to the current position set with `text_position/3`. Default: `:left`.","ref":"Mudbrick.html#text/3-options","title":"Options - Mudbrick.text/3","type":"function"},{"doc":"Set the position for future calls to `text/3`, relative to the current page's\nbottom left corner. Starts a new PDF text object (`BT`/`ET`).","ref":"Mudbrick.html#text_position/3","title":"Mudbrick.text_position/3","type":"function"},{"doc":"","ref":"Mudbrick.Document.html","title":"Mudbrick.Document","type":"module"},{"doc":"","ref":"Mudbrick.Document.html#t:t/0","title":"Mudbrick.Document.t/0","type":"type"},{"doc":"","ref":"Mudbrick.Page.html","title":"Mudbrick.Page","type":"module"},{"doc":"Returns predefined page sizes in points.","ref":"Mudbrick.Page.html#size/1","title":"Mudbrick.Page.size/1","type":"function"},{"doc":"iex> Mudbrick.Page.size(:a4)\n    {597.6, 842.4}\n\n    iex> Mudbrick.Page.size(:a3)\n    {842.4, 1188.0}\n\n    iex> Mudbrick.Page.size(:letter)\n    {612.0, 792}","ref":"Mudbrick.Page.html#size/1-examples","title":"Examples - Mudbrick.Page.size/1","type":"function"},{"doc":"Useful for testing PDF documents.\n\nWhile these predicates do check the PDF in a black-box way, it's not expected\nthat they will work on all PDFs found in the wild.","ref":"Mudbrick.Predicates.html","title":"Mudbrick.Predicates","type":"module"},{"doc":"Checks for presence of `text` in the `pdf` `iodata`. Searches compressed and uncompressed data.\n\nThis arity only works with text that can be found in literal form inside a stream, compressed or uncompressed,","ref":"Mudbrick.Predicates.html#has_text?/2","title":"Mudbrick.Predicates.has_text?/2","type":"function"},{"doc":"Checks for presence of `text` in the `pdf` `iodata`. Searches compressed and uncompressed data.\n\nThis arity requires you to pass the raw font data in which the text is\nexpected to be written. It must be present in raw hexadecimal form\ncorresponding to the font's glyph IDs.\n\nThe [OpenType](https://hexdocs.pm/opentype) library is used to find font\nfeatures, such as ligatures, which are expected to have been used in the PDF.","ref":"Mudbrick.Predicates.html#has_text?/3","title":"Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"- `:in_font` - raw font data in which the text is expected.","ref":"Mudbrick.Predicates.html#has_text?/3-options","title":"Options - Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"iex> Mudbrick.Predicates.has_text?(\"some-pdf\", \"hello\", in_font: Mudbrick.TestHelper.bodoni())","ref":"Mudbrick.Predicates.html#has_text?/3-example","title":"Example - Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"","ref":"Mudbrick.ContentStream.InvalidColour.html","title":"Mudbrick.ContentStream.InvalidColour","type":"exception"},{"doc":"","ref":"Mudbrick.Font.NotMeasured.html","title":"Mudbrick.Font.NotMeasured","type":"exception"},{"doc":"","ref":"Mudbrick.Font.NotSet.html","title":"Mudbrick.Font.NotSet","type":"exception"},{"doc":"","ref":"Mudbrick.Font.Unregistered.html","title":"Mudbrick.Font.Unregistered","type":"exception"},{"doc":"","ref":"Mudbrick.Image.NotSupported.html","title":"Mudbrick.Image.NotSupported","type":"exception"},{"doc":"","ref":"Mudbrick.Image.Unregistered.html","title":"Mudbrick.Image.Unregistered","type":"exception"},{"doc":"# Mudbrick\n\n[Documentation](https://hexdocs.pm/mudbrick)\n\nEarly-stages PDF generator, beelining for:\n\n- PDF 2.0 support.\n- In-process, pure functional approach.\n- OpenType support.\n- Special characters and ligatures, like ₛᵤ₆ₛ꜀ᵣᵢₚₜₛ for chemical compounds etc.\n\nCurrently working:\n\n- OpenType fonts with ligatures and special characters.\n- Text positioning.\n- Right alignment.\n- Coloured text.\n- JPEG images.\n- Compression.\n\nTo do:\n\n- Other image formats.\n- Font subsetting.\n- Vector graphics.","ref":"readme.html","title":"Mudbrick","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:mudbrick, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Mudbrick","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}